import { ServiceName } from '@cbjsdev/shared';
import { CouchbaseHttpApiConfig } from '../../../types';
export type InitClusterParams = {
    username: string;
    password: string;
    /**
     * The IP address or domain name that will be the name of the node established as a single-node cluster.
     *
     * @default 127.0.0.1
     */
    hostname?: string;
    data_path?: string;
    index_path?: string;
    cbas_path?: string;
    eventing_path?: string;
    java_home?: string;
    sendStats?: boolean;
    clusterName?: string;
    /**
     * List of services to be hosted on this cluster.
     */
    services: [ServiceName, ...ServiceName[]];
    memoryQuota?: number;
    indexMemoryQuota?: number;
    eventingMemoryQuota?: number;
    ftsMemoryQuota?: number;
    cbasMemoryQuota?: number;
    afamily?: 'ipv4' | 'ipv6';
    afamilyOnly?: boolean;
    nodeEncryption?: 'on' | 'off';
    indexerStorageMode?: 'plasma' | 'magma';
    port?: 'SAME' | number;
    /**
     * Comma separated list of hosts allowed to join the cluster.
     *
     * @since 7.1.1
     * @example *.mysubnet.org,192.168.0.0/16
     */
    allowedHosts?: string;
};
export declare function requestInitCluster({ hostname, secure }: Pick<CouchbaseHttpApiConfig, 'hostname' | 'secure'>, initClusterParams: InitClusterParams): Promise<Response>;
