/*
 * Copyright (c) 2023-Present Jonathan MASSUCHETTI <jonathan.massuchetti@dappit.fr>.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import fetch from 'cross-fetch';
import { jsonToUrlSearchParams } from '@cbjsdev/shared';
import { MANAGEMENT_PORT } from '../../../utils/ports';
export async function requestInitCluster({ hostname, secure }, initClusterParams) {
    const protocol = secure ? 'https' : 'http';
    const url = `${protocol}://${hostname}:${MANAGEMENT_PORT}/clusterInit`;
    const services = initClusterParams.services.join(',');
    const body = {
        port: 'SAME',
        sendStats: false,
        ...initClusterParams,
        services,
    };
    const payload = jsonToUrlSearchParams(body);
    return await fetch(url, {
        method: 'POST',
        body: payload,
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
    });
}
//# sourceMappingURL=requestInitCluster.js.map