import { ApiAnalyticsLinkSharedProperties } from './ApiAnalyticsLink';
export type ApiAnalyticsAzureAuthSharedKey = {
    /**
     * Account name.
     * Used for Azure Active Directory with client certificate authentication.
     */
    accountName: string;
    /**
     * Account key for shared key authentication.
     */
    accountKey: string;
};
export type ApiAnalyticsAzureAuthClientSecret = {
    /**
     * The client ID for the registered application.
     *
     * Used for Azure Active Directory with client secret authentication.
     */
    clientId: string;
    /**
     * The client secret for the registered application.
     *
     * Used for Azure Active Directory with client secret authentication.
     */
    clientSecret: string;
    /**
     * The tenant ID where the registered application is created.
     *
     * Used for Azure Active Directory with client secret authentication.
     */
    tenantId?: string;
};
export type ApiAnalyticsAzureAuthClientCertificate = {
    /**
     * The client ID for the registered application.
     *
     * Used for Azure Active Directory with client certificate authentication.
     */
    clientId: string;
    /**
     * The client certificate.
     *
     * Used for Azure Active Directory with client certificate authentication.
     */
    clientCertificate: string;
    /**
     * The client certificate password for the registered application, if the client certificate is password-protected.
     *
     * Used for Azure Active Directory with client certificate authentication.
     */
    clientCertificatePassword?: string;
    /**
     * The tenant ID where the registered application is created.
     *
     * Used for Azure Active Directory with client certificate authentication.
     */
    tenantId?: string;
};
export type ApiAnalyticsAzureAuthSharedAccessSignature = {
    /**
     * Used for Azure shared access signature.
     */
    sharedAccessSignature: string;
};
export type ApiAnalyticsAzureAuthManagedIdentity = {
    /**
     * Used for managed identity authentication.
     *
     * Only available if the application is running on an Azure instance, e.g. an Azure virtual machine.
     */
    managedIdentityId: string;
};
export type ApiAnalyticsAzureAuthenticationConfig = ApiAnalyticsAzureAuthSharedKey | ApiAnalyticsAzureAuthClientCertificate | ApiAnalyticsAzureAuthClientSecret | ApiAnalyticsAzureAuthSharedAccessSignature | ApiAnalyticsAzureAuthManagedIdentity;
export type ApiAnalyticsAzureRemoteLink = {
    type: 'azureblob';
    endpoint?: string;
} & ApiAnalyticsLinkSharedProperties & ApiAnalyticsAzureAuthenticationConfig;
